==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/connect/kotlin/outputs/UserHierarchyGroupHierarchyPath.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property levelFives A block that defines the details of level five. The level block is documented below.
 * @property levelFours A block that defines the details of level four. The level block is documented below.
 * @property levelOnes A block that defines the details of level one. The level block is documented below.
 * @property levelThrees A block that defines the details of level three. The level block is documented below.
 * @property levelTwos A block that defines the details of level two. The level block is documented below.
 */
public data class UserHierarchyGroupHierarchyPath(
    public val levelFives: List<UserHierarchyGroupHierarchyPathLevelFife>? = null,
    public val levelFours: List<UserHierarchyGroupHierarchyPathLevelFour>? = null,
    public val levelOnes: List<UserHierarchyGroupHierarchyPathLevelOne>? = null,
    public val levelThrees: List<UserHierarchyGroupHierarchyPathLevelThree>? = null,
    public val levelTwos: List<UserHierarchyGroupHierarchyPathLevelTwo>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.connect.outputs.UserHierarchyGroupHierarchyPath):
            UserHierarchyGroupHierarchyPath = UserHierarchyGroupHierarchyPath(
            levelFives = javaType.levelFives().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelFife.Companion.toKotlin(args0)
                })
            }),
            levelFours = javaType.levelFours().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelFour.Companion.toKotlin(args0)
                })
            }),
            levelOnes = javaType.levelOnes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelOne.Companion.toKotlin(args0)
                })
            }),
            levelThrees = javaType.levelThrees().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelThree.Companion.toKotlin(args0)
                })
            }),
            levelTwos = javaType.levelTwos().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelTwo.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/connect/kotlin/outputs/UserHierarchyGroupHierarchyPath.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property levelFives A block that defines the details of level five. The level block is documented below.
 * @property levelFours A block that defines the details of level four. The level block is documented below.
 * @property levelOnes A block that defines the details of level one. The level block is documented below.
 * @property levelThrees A block that defines the details of level three. The level block is documented below.
 * @property levelTwos A block that defines the details of level two. The level block is documented below.
 */
public data class UserHierarchyGroupHierarchyPath(
    public val levelFives: List<UserHierarchyGroupHierarchyPathLevelFife>? = null,
    public val levelFours: List<UserHierarchyGroupHierarchyPathLevelFour>? = null,
    public val levelOnes: List<UserHierarchyGroupHierarchyPathLevelOne>? = null,
    public val levelThrees: List<UserHierarchyGroupHierarchyPathLevelThree>? = null,
    public val levelTwos: List<UserHierarchyGroupHierarchyPathLevelTwo>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.connect.outputs.UserHierarchyGroupHierarchyPath): UserHierarchyGroupHierarchyPath = UserHierarchyGroupHierarchyPath(
            levelFives = javaType.levelFives().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelFife.Companion.toKotlin(args0)
                })
            }),
            levelFours = javaType.levelFours().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelFour.Companion.toKotlin(args0)
                })
            }),
            levelOnes = javaType.levelOnes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelOne.Companion.toKotlin(args0)
                })
            }),
            levelThrees = javaType.levelThrees().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelThree.Companion.toKotlin(args0)
                })
            }),
            levelTwos = javaType.levelTwos().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.UserHierarchyGroupHierarchyPathLevelTwo.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
